@@ -14,7 +14,7 @@ use clap::{Parser, Subcommand};
 use maturin::{ci::GenerateCI, init_project, new_project, GenerateProjectOptions};
 use maturin::{
     develop, write_dist_info, BridgeModel, BuildOptions, CargoOptions, DevelopOptions, PathWriter,
-    PlatformTag, PythonInterpreter, Target,
+    PlatformTag, PythonInterpreter, Target, TargetTriple,
 };
 #[cfg(feature = "schemars")]
 use maturin::{generate_json_schema, GenerateJsonSchemaOptions};
@@ -95,7 +95,7 @@ enum Command {
     /// Search and list the available python installations
     ListPython {
         #[arg(long)]
-        target: Option<String>,
+        target: Option<TargetTriple>,
     },
     #[command(name = "develop", alias = "dev")]
     /// Install the crate as module in the current virtualenv
@@ -282,12 +282,16 @@ fn pep517(subcommand: Pep517Command) -> Result<()> {
 
             // Since afaik all other PEP 517 backends also return linux tagged wheels, we do so too
             let tags = match context.bridge() {
-                BridgeModel::Bindings(..) | BridgeModel::Bin(Some(..)) => {
-                    vec![context.interpreter[0].get_tag(&context, &[PlatformTag::Linux])?]
-                }
-                BridgeModel::BindingsAbi3(major, minor) => {
-                    let platform = context.get_platform_tag(&[PlatformTag::Linux])?;
-                    vec![format!("cp{major}{minor}-abi3-{platform}")]
+                BridgeModel::PyO3(bindings) | BridgeModel::Bin(Some(bindings)) => {
+                    match bindings.abi3 {
+                        Some((major, minor)) => {
+                            let platform = context.get_platform_tag(&[PlatformTag::Linux])?;
+                            vec![format!("cp{major}{minor}-abi3-{platform}")]
+                        }
+                        None => {
+                            vec![context.interpreter[0].get_tag(&context, &[PlatformTag::Linux])?]
+                        }
+                    }
                 }
                 BridgeModel::Bin(None) | BridgeModel::Cffi | BridgeModel::UniFfi => {
                     context.get_universal_tags(&[PlatformTag::Linux])?.1
@@ -295,8 +299,8 @@ fn pep517(subcommand: Pep517Command) -> Result<()> {
             };
 
             let mut writer = PathWriter::from_path(metadata_directory);
-            write_dist_info(&mut writer, &context.metadata23, &tags)?;
-            println!("{}", context.metadata23.get_dist_info_dir().display());
+            write_dist_info(&mut writer, &context.metadata24, &tags)?;
+            println!("{}", context.metadata24.get_dist_info_dir().display());
         }
         Pep517Command::BuildWheel {
             build_options,
@@ -424,8 +428,8 @@ fn run() -> Result<()> {
         }
         Command::ListPython { target } => {
             let found = if target.is_some() {
-                let target = Target::from_target_triple(target)?;
-                PythonInterpreter::find_by_target(&target, None)
+                let target = Target::from_target_triple(target.as_ref())?;
+                PythonInterpreter::find_by_target(&target, None, None)
             } else {
                 let target = Target::from_target_triple(None)?;
                 // We don't know the targeted bindings yet, so we use the most lenient
@@ -437,7 +441,7 @@ fn run() -> Result<()> {
             }
         }
         Command::Develop(develop_options) => {
-            let target = Target::from_target_triple(develop_options.cargo_options.target.clone())?;
+            let target = Target::from_target_triple(develop_options.cargo_options.target.as_ref())?;
             let venv_dir = detect_venv(&target)?;
             develop(develop_options, &venv_dir)?;
         }
